# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['selenium_screenshots']

package_data = \
{'': ['*']}

install_requires = \
['char>=0.1.2,<0.2.0',
 'local-simple-database>=0.1.10,<0.2.0',
 'tqdm>=4.64.0,<5.0.0']

setup_kwargs = {
    'name': 'selenium-screenshots',
    'version': '0.1.3',
    'description': 'python package which helps to create many screenshots for selenium.webdriver',
    'long_description': '====================\nselenium_screenshots\n====================\n\n\n.. image:: https://img.shields.io/github/last-commit/stas-prokopiev/selenium_screenshots\n   :target: https://img.shields.io/github/last-commit/stas-prokopiev/selenium_screenshots\n   :alt: GitHub last commit\n\n.. image:: https://img.shields.io/github/license/stas-prokopiev/selenium_screenshots\n    :target: https://github.com/stas-prokopiev/selenium_screenshots/blob/master/LICENSE.txt\n    :alt: GitHub license<space><space>\n\n.. image:: https://readthedocs.org/projects/selenium_screenshots/badge/?version=latest\n    :target: https://selenium_screenshots.readthedocs.io/en/latest/?badge=latest\n    :alt: Documentation Status\n\n.. image:: https://travis-ci.org/stas-prokopiev/selenium_screenshots.svg?branch=master\n    :target: https://travis-ci.org/stas-prokopiev/selenium_screenshots\n\n.. image:: https://img.shields.io/pypi/v/selenium_screenshots\n   :target: https://img.shields.io/pypi/v/selenium_screenshots\n   :alt: PyPI\n\n.. image:: https://img.shields.io/pypi/pyversions/selenium_screenshots\n   :target: https://img.shields.io/pypi/pyversions/selenium_screenshots\n   :alt: PyPI - Python Version\n\n\n.. contents:: **Table of Contents**\n\nShort Overview.\n=========================\nselenium_screenshots is a python package that helps to create many screenshots for selenium webdrivers.\n\nExample\n------------------------------\n\n.. code-block:: python\n\n    from selenium import webdriver\n    from selenium_screenshots import make_screenshot\n    # Please define here any webdriver which you would like to use E.G. driver = webdriver.Chrome()\n    # When you would want to create a screenshot, just call\n    make_screenshot(driver)\n    make_screenshot(driver, "some_description")\n    make_screenshot(driver, "characters_%%forbidden_in_the_..filename")\n\nAs the result you will get screenshots in the directory: **./screenshots/...**\n\n- 1.png\n- 2_some_description.png\n- 3_characters___forbidden_in_the___filename.png\n\nIf you run this code some other time then you\'ll get 3 more screenshots:\n\n- 1.png\n- 2_some_description.png\n- 3_characters___forbidden_in_the___filename.png\n- 4.png\n- 5_some_description.png\n- 6_characters___forbidden_in_the___filename.png\n\nAs you can see user shouldn\'t worry about screenshot\'s numbers as they will be handled automatically.\n\nInstallation via pip:\n======================\n\n.. code-block:: bash\n\n    pip install selenium_screenshots\n\nBasic Usage\n=========================\n\nFull signature of selenium_screenshots.make_screenshot(...)\n--------------------------------------------------------------------------------------------------\n\n.. code-block:: python\n\n    from selenium_screenshots import make_screenshot\n\n    make_screenshot(\n        webdriver,\n        str_description="",\n        str_path_dir_with_screenshots="screenshots",\n    )\n\nArguments\n^^^^^^^^^^^^^^\n\n#. **webdriver**:\n    The only mandatary argument. Any selenium webdriver which to use for making of screenshot.\n#. **str_description=""**:\n    | Description of the screenshot to add to the screenshot filename.\n    | If in the screenshot description will be used symbols forbidden in the filenames they will be replaced on "_".\n    | If filename of a new screenshot is longer than 50 symbols then it will be cut to 50.\n#. **str_path_dir_with_screenshots="screenshots"**:\n    Path to the directory where you want to save a new screenshot\n\nAdvanced Usage\n=========================\n\n**selenium_screenshots.Screenshots(...)**\n--------------------------------------------------------------------------------------------------\n\n| Firstly, you have to define an object of class Screenshots to be able to handle screenshots.\n| This object will be named **screenshots_handler** in the code below.\n\n.. code-block:: python\n\n    from selenium import webdriver\n    from selenium_screenshots.main import Screenshots\n\n    # Please define here any webdriver which you would like to use E.G. driver = webdriver.Chrome()\n    screenshots_handler = Screenshots(\n            webdriver,\n            str_path_dir_with_screenshots="screenshots",\n            int_screenshots_to_delete_half=9999,\n            int_max_length_of_filename=50,\n    )\n\nArguments\n^^^^^^^^^^^^^^\n\n#. **webdriver**:\n    The only mandatary argument. Any selenium webdriver which to use for making of screenshots.\n#. **str_path_dir_with_screenshots="screenshots"**:\n    Path to directory where to save screenshots.\n#. **int_screenshots_to_delete_half=9999**:\n    Number of the screenshots in the directory when try to delete most old half\n#. **int_max_length_of_filename=50**:\n    | Max length of a new screenshot filename.\n    | If filename of a new screenshot is longer then filename will be cut.\n\nMethods of **screenshots_handler** object\n--------------------------------------------------------------------------------------------------\n\nscreenshots_handler.create_screenshot(...)\n^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n\nThis method do exactly the same as **selenium_screenshots.make_screenshot(...)** in the **Basic Usage**\n\n.. code-block:: python\n\n    screenshots_handler.create_screenshot(str_description="")\n\n#. **str_description=""**:\n    | Description of the screenshot to add to the screenshot filename.\n    | If in the screenshot description is used symbols forbidden in the filenames they will be replaced on "_".\n    | If filename of a new screenshot is longer than N symbols then it will be cut to N.\n\nscreenshots_handler.delete_all_screenshots(...)\n^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n\n| This method will delete all screenshots in the directory.\n| Max used screenshot number won\'t be lost, so new screenshot will have next number rather than 1.\n\n.. code-block:: python\n\n    screenshots_handler.delete_all_screenshots()\n\n\nscreenshots_handler.delete_not_unique_screenshots(...)\n^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n\n| This method will delete screenshots with not unique descriptions.\n\n.. code-block:: python\n\n    screenshots_handler.delete_not_unique_screenshots(\n        is_to_delete_screenshots_without_description=False)\n\n#. **is_to_delete_screenshots_without_description=False**:\n    | Flag if to delete screenshots without description\n\nHow to create screenshot every time when you caught an Exception\n---------------------------------------------------------------------------\n\n| You can use this python package to make screenshots for every exception\n| with preserved description of an error in the screenshot filename.\n\n\n.. code-block:: python\n\n    from selenium_screenshots import make_screenshot\n\n    try:\n        # Some code which you would like to test\n    except Exception as ex:\n        make_screenshot(webdriver, str_description=str(ex))\n        raise\n\nLinks\n=====\n\n    * `PYPI <https://pypi.org/project/selenium_screenshots/>`_\n    * `readthedocs <https://selenium_screenshots.readthedocs.io/en/latest/>`_\n    * `GitHub <https://github.com/stas-prokopiev/selenium_screenshots>`_\n\nProject local Links\n===================\n\n    * `CHANGELOG <https://github.com/stas-prokopiev/selenium_screenshots/blob/master/CHANGELOG.rst>`_.\n    * `CONTRIBUTING <https://github.com/stas-prokopiev/selenium_screenshots/blob/master/CONTRIBUTING.rst>`_.\n\nContacts\n========\n\n    * Email: stas.prokopiev@gmail.com\n    * `vk.com <https://vk.com/stas.prokopyev>`_\n    * `Facebook <https://www.facebook.com/profile.php?id=100009380530321>`_\n\nLicense\n=======\n\nThis project is licensed under the MIT License.\n\n',
    'author': 'stanislav prokopyev',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/stas-prokopiev/selenium_screenshots',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
